@@ -73,7 +73,7 @@ class MappingKey(collections.abc.Set, iterables.ReprStrMixin):
         return ' | '.join(str(alias) for alias in self._aliases)
 
 
-class KeyMap(iterables.MappingBase):
+class KeyMap(iterables.MappingBase, iterables.ReprStrMixin):
     """A collection that associates common aliases."""
 
     def __init__(self, *keys: Aliases) -> None:
@@ -84,8 +84,8 @@ class KeyMap(iterables.MappingBase):
             An iterable collection of associated keys. Each key may be a string
             or an iterable of strings (including instances of `~MappingKey`).
         """
-        self._aliased = [MappingKey(key) for key in keys]
-        self._flat = [key for alias in self._aliased for key in alias]
+        self._groups = [MappingKey(key) for key in keys]
+        self._flat = [key for group in self._groups for key in group]
         super().__init__(self._flat)
 
     def __getitem__(self, __k) -> MappingKey:
@@ -99,7 +99,7 @@ class KeyMap(iterables.MappingBase):
         """
         s = str(__k)
         m = MappingKey(__k)
-        alias = (k for k in self._aliased if s in k or m == k)
+        alias = (k for k in self._groups if s in k or m == k)
         try:
             found = next(alias)
         except StopIteration as err:
@@ -107,6 +107,24 @@ class KeyMap(iterables.MappingBase):
         else:
             return found
 
+    def without(self, *keys: typing.Union[str, MappingKey]):
+        """Create a new keymap after removing `keys`."""
+        subset = [
+            group
+            for group in self._groups
+            if (
+                # none of the keys is in this group
+                all(key not in group for key in keys)
+                and
+                # this group is not one of the keys
+                group not in keys
+            )
+        ]
+        return type(self)(*subset)
+
+    def __str__(self) -> str:
+        return ', '.join(f"{str(k)!r}" for k in self._groups)
+
 
 def keysfrom(
     mapping: typing.Mapping[str, typing.Mapping[str, typing.Any]],
@@ -708,7 +726,7 @@ class MutableMapping(Mapping, collections.abc.MutableMapping):
         }
 
     def alias(self, key: str, *aliases: str, include=False):
-        """Get the alias for an existing key.
+        """Get or set the alias(es) for an existing key.
         
         Parameters
         ----------
