@@ -189,7 +189,13 @@ def slice_to_range(s: slice, stop: int=0) -> range:
 
 def string_to_list(string: str) -> list:
     """Convert a string representation of a list to a list"""
-    return [numerical.cast(i) for i in string.strip('[]').split(',')]
+    if not (string.startswith('[') and string.endswith(']')):
+        raise TypeError(f"Can't convert {string!r} to a list") from None
+    inside = string.strip('[]')
+    if not inside:
+        return []
+    items = [item.strip(" ''") for item in inside.split(',')]
+    return [numerical.cast(i) for i in items]
 
 
 def naked(targets: typing.Any) -> bool:
@@ -1045,8 +1051,8 @@ class Table(MappingBase):
         unique entry with all the key-value pairs. Both searches will raise a
         `TableLookupError` if they fail to find a unique entry, or a
         `TableKeyError` if one of the given keys does not exist in all table
-        entries. The iterative search will raise an `AmbiguousRequestError` if the
-        given key-value pairs are insufficient to determine a unique entry.
+        entries. The iterative search will raise an `AmbiguousRequestError` if
+        the given key-value pairs are insufficient to determine a unique entry.
 
         Parameters
         ----------
@@ -1054,7 +1060,8 @@ class Table(MappingBase):
             Fail if any of the given key-value pairs is not in the collection.
 
         **request : mapping
-            Key-value pairs that define the search criteria. Each key must appear in all table entries.
+            Key-value pairs that define the search criteria. Each key must
+            appear in all table entries.
 
             Key-value pairs in which each requested key is a key in every entry
             of the collection. Each requested value may correspond to its
@@ -1296,7 +1303,11 @@ class SeparableTypeError(TypeError):
         return f"{self.arg!r} is not separable"
 
 
-class whole(collections.abc.Collection, metaclass=NonStrIterable):
+class whole(
+    collections.abc.Collection,
+    typing.Generic[T],
+    ReprStrMixin,
+    metaclass=NonStrIterable):
     """A collection of independent members.
 
     This class represents iterable collections with members that have meaning
@@ -1358,10 +1369,6 @@ class whole(collections.abc.Collection, metaclass=NonStrIterable):
         """A simplified representation of this object."""
         return str(self.arg)
 
-    def __repr__(self) -> str:
-        """An unambiguous representation of this object."""
-        return f"{self.__class__.__qualname__}({self})"
-
 
 def distribute(a, b):
     """Distribute `a` and `b` over each other.
@@ -1493,8 +1500,9 @@ def hastype(
     __obj,
     __types: typing.Union[type, typing.Tuple[type, ...]],
     *wrappers: typing.Type[typing.Iterable],
+    strict: bool=False,
 ) -> bool:
-    """True if an object is a certain type or contains only certain __types.
+    """True if an object is a certain type or contains certain types.
     
     Parameters
     ----------
@@ -1507,9 +1515,13 @@ def hastype(
     *wrappers : iterable type
         Zero or more iterable types of which the target object may be an
         instance. If the target object is an instance of a given wrapper type,
-        this function will test whether every members of the target object is an
+        this function will test whether every member of the target object is an
         instance of the given types.
 
+    strict : bool, default=False
+        If true, return ``True`` if `__obj` contains only `__type`. Otherwise,
+        return ``True`` if `__obj` contains at least one of `__types`.
+
     Examples
     --------
     When called without wrappers, this function is identical to ``isinstance``:
@@ -1522,7 +1534,10 @@ def hastype(
 
     >>> iterables.hastype([1, 2], list)
     True
-    
+
+    Note that in these cases, `strict` is irrelevant because this function
+    checks only the type of `__obj`.
+
     The target object contains the given type but ``list`` is not a declared
     wrapper:
     
@@ -1539,9 +1554,14 @@ def hastype(
     >>> iterables.hastype([1, 2], int, tuple)
     False
 
-    Each member of a declared wrapper type must be one of the target types:
+    By default, only one member of a wrapped object needs to be an instance of one of the target types:
 
     >>> iterables.hastype([1, 2.0], int, list)
+    True
+
+    If ``strict=True``, each member must be one of the target types:
+
+    >>> iterables.hastype([1, 2.0], int, list, strict=True)
     False
 
     Multiple target types must be passed as a ``tuple``, just as when calling
@@ -1552,12 +1572,103 @@ def hastype(
 
     Otherwise, this function will interpret them as wrapper types:
 
-    >>> iterables.hastype([1, 2.0], int, float, list)
+    >>> iterables.hastype([1, 2.0], int, float, list, strict=True)
     False
     """
     if isinstance(__obj, __types):
         return True
     for wrapper in wrappers:
         if isinstance(__obj, wrapper):
-            return all(isinstance(i, __types) for i in __obj)
+            check = all if strict else any
+            return check(isinstance(i, __types) for i in __obj)
     return False
+
+
+G = typing.TypeVar('G')
+
+
+class Guard:
+    """Substitute default values for exceptions.
+
+    This class wraps a callable object in `try/except` logic that substitutes a
+    default value when calling that object raises a known exception. The default
+    behavior is to substitute ``None``, but users may specify a specific
+    substitution value when registering a known exception (see `~Guard.catch`).
+    
+    Notes
+    -----
+    This class was inspired by https://stackoverflow.com/a/8915613/4739101.
+    """
+
+    def __init__(self, __callable: typing.Callable[..., T]) -> None:
+        self._call = __callable
+        self._substitutions = {}
+
+    def catch(self, exception: Exception, /, value: G=None):
+        """Register a known exception and optional substitution value.
+        
+        Parameters
+        ----------
+        exception
+            An exception class to catch when calling the guarded object.
+
+        value, optional
+            The value to return from `~Guard.call` when calling the guarded
+            object raises `exception`. The default value is ``None``. There is
+            one special case: Registering `exception` with ``value = ...``
+            (i.e., the built-in ``Ellipsis`` object), will cause `~Guard.call` to return
+            the given argument(s). See `~Guard.call` for more information about
+            the form of the return value in this case.
+        """
+        self._substitutions[exception] = value
+
+    def call(self, *args, **kwargs) -> typing.Union[T, G]:
+        """Call the guarded object with the given arguments.
+        
+        Parameters
+        ----------
+        *args
+            Positional arguments to pass to the guarded object.
+
+        **kwargs
+            Keyword arguments to pass to the guarded object.
+
+        Returns
+        -------
+        The result of calling the guarded object, or an associated default
+        value, or the given arguments.
+        
+        If no exceptions arose when calling the guarded object, this method will
+        return the result of that call.
+
+        If calling the guarded object raises a known exception and the value
+        associated with that exception is not ``...`` (the built-in ``Ellipsis``
+        object), this method will return the associated value.
+        
+        If calling the guarded object raises a known exception and the value
+        associated with that exception is ``...``, this method will return the
+        given arguments. The return type in this case depends on the given
+        arguments. If the user passes only a single positional argument, this
+        method will return that argument. If the user passes only positional
+        arguments, this method will return the equivalent ``tuple``. If the user
+        passes only keyword arguments, this method will return the equivalent
+        ``dict``. If the user passes positional and keyword arguments, this
+        method will return a ``tuple`` containing the corresponding equivalent
+        ``tuple`` and ``dict``.
+        
+        If calling the guarded object raises an exception that is unknown to
+        this instance, that exception will propagate up to the caller as usual.
+        """
+        try:
+            return self._call(*args, **kwargs)
+        except tuple(self._substitutions) as err:
+            value = self._substitutions[type(err)]
+            if value != Ellipsis:
+                return value
+            if not kwargs:
+                if len(args) == 1:
+                    return args[0]
+                return args
+            if not args:
+                return kwargs
+            return args, kwargs
