@@ -1,3 +1,4 @@
+import collections.abc
 import contextlib
 import numbers
 import typing
@@ -5,9 +6,12 @@ import typing
 import numpy
 import numpy.typing
 
+from goats.core import algebraic
+from goats.core import fundamental
 from goats.core import iterables
 from goats.core import measurable
 from goats.core import metadata
+from goats.core import metric
 
 
 Instance = typing.TypeVar('Instance', bound='Quantity')
@@ -19,7 +23,7 @@ class Quantity(measurable.Quantity, metadata.NameMixin):
     @typing.overload
     def __init__(
         self: Instance,
-        __data: measurable.Real,
+        __data: algebraic.Real,
         *,
         unit: metadata.UnitLike=None,
         name: typing.Union[str, typing.Iterable[str]]=None,
@@ -43,7 +47,7 @@ class Quantity(measurable.Quantity, metadata.NameMixin):
             self.display['__repr__'].insert(2, "name='{name}'")
 
 
-class Scalar(Quantity, measurable.ScalarOperators):
+class Scalar(Quantity, algebraic.Scalar):
     """A single-valued named quantity."""
 
     @typing.overload
@@ -77,6 +81,41 @@ class Scalar(Quantity, measurable.ScalarOperators):
         raise TypeError(f"Can't iterate over {type(self)!r}") from None
 
 
+class Constants(collections.abc.Mapping):
+    """Fundamental physical constants in a given metric system."""
+    def __init__(self, system: str) -> None:
+        self.system = system.lower()
+        self._mapping = fundamental.CONSTANTS.copy()
+
+    def __len__(self) -> int:
+        """The number of defined constants."""
+        return len(self._mapping)
+
+    def __iter__(self) -> typing.Iterator:
+        """Iterate over defined constants."""
+        return iter(self._mapping)
+
+    def __getitem__(self, name: str):
+        """Create the named constant or raise an error."""
+        if name in self._mapping:
+            found = self._get_attributes(name)
+            return Scalar(found['value'], unit=found['unit'])
+        raise KeyError(name)
+
+    def _get_attributes(self, name: str) -> dict:
+        """Get the value and unit for a named constant, if possible."""
+        definition = self._mapping[name]
+        if 'all' in definition:
+            return {'value': definition['all'], 'unit': None}
+        if this := definition.get(self.system):
+            return this
+        raise ValueError(f"Unknown constant: {name!r}")
+
+    def __repr__(self) -> str:
+        """An unambiguous representation of this object."""
+        return f"{self.__class__.__qualname__}({self.system})"
+
+
 class Vector(Quantity):
     """A multi-valued named quantity.
 
@@ -92,7 +131,7 @@ class Vector(Quantity):
     @typing.overload
     def __init__(
         self: Instance,
-        __data: typing.Union[measurable.Real, numpy.typing.ArrayLike],
+        __data: typing.Union[algebraic.Real, numpy.typing.ArrayLike],
         *,
         unit: metadata.UnitLike=None,
         name: typing.Union[str, typing.Iterable[str]]=None,
@@ -102,6 +141,14 @@ class Vector(Quantity):
     def __init__(
         self: Instance,
         __data: measurable.Measurement,
+        *,
+        name: typing.Union[str, typing.Iterable[str]]=None,
+    ) -> None: ...
+
+    @typing.overload
+    def __init__(
+        self: Instance,
+        scalar: Scalar,
     ) -> None: ...
 
     @typing.overload
@@ -114,6 +161,9 @@ class Vector(Quantity):
         if isinstance(__data, measurable.Measurement):
             meta = {'unit': __data.unit}
             __data = __data.values
+        elif isinstance(__data, Scalar):
+            meta = {k: getattr(__data, k) for k in ('unit', 'name')}
+            __data = __data.data
         array = numpy.asfarray(list(iterables.whole(__data)))
         super().__init__(array, **meta)
 
@@ -179,14 +229,34 @@ Instance = typing.TypeVar('Instance', bound='Array')
 class Array(numpy.lib.mixins.NDArrayOperatorsMixin, Quantity):
     """Base class for array-like objects."""
 
-    def __init__(self, *args, **kwargs) -> None:
-        super().__init__(*args, **kwargs)
+    def __new__(cls, *args, **kwargs):
+        """Create an instance of the appropriate object."""
+        if len(args) == 1:
+            data = args[0]
+            if isinstance(data, numbers.Number):
+                return Scalar(data, **kwargs)
+        return super().__new__(cls)
+
+    def __init__(self, __data, **meta) -> None:
+        """Initialize an array from arguments."""
+        super().__init__(__data, **meta)
         self._scale = 1.0
-        self._full_array = None
+        self._full_array = getattr(__data, '_array', None)
         self._ndim = None
         self._shape = None
         self.display.register(data='_get_data_type')
 
+    @property
+    def data(self):
+        """The initial data.
+        
+        This attribute represents the data-containing object used to create this
+        instance. It does not necessarily represent the current array data,
+        which may differ as a result of changing the instance unit, or due to
+        other allowed updates defined on subclasses.
+        """
+        return super().data
+
     def _get_data_type(self):
         """Internal helper for displaying the type of data object."""
         return self.data.__class__
@@ -238,23 +308,41 @@ class Array(numpy.lib.mixins.NDArrayOperatorsMixin, Quantity):
         for this in ['data', '_array']:
             attr = getattr(self, this)
             with contextlib.suppress(AttributeError):
-                if value := getattr(attr, name):
-                    return value
+                if hasattr(attr, name):
+                    # avoid false negative when value == 0
+                    return getattr(attr, name)
         raise AttributeError(f"Could not find an attribute named {name!r}")
 
-    _builtin = (int, slice, type(...))
+    _builtin = (int, slice, type(...), type(None))
 
-    def __getitem__(self, *args: typing.Union[metadata.UnitLike, IndexLike]):
+    @typing.overload
+    def __getitem__(
+        self: Instance,
+        unit: typing.Union[str, metric.Unit],
+    ) -> Instance: ...
+
+    @typing.overload
+    def __getitem__(
+        self,
+        *args: IndexLike,
+    ) -> typing.Union[Scalar, 'Array', Instance]: ...
+
+    def __getitem__(self, *args):
         """Create a new instance from a subset of data."""
         if len(args) == 1 and isinstance(args[0], metadata.UnitLike):
             return super().__getitem__(args[0])
         unwrapped = iterables.unwrap(args)
-        if iterables.hastype(unwrapped, self._builtin, tuple):
+        if iterables.hastype(unwrapped, self._builtin, tuple, strict=True):
             return self._subscript_standard(unwrapped)
         return self._subscript_custom(unwrapped)
 
-    def apply_unit(self, new: metadata.UnitLike):
-        self._scale *= new // self._unit
+    def apply_unit(self, unit: metadata.UnitLike):
+        # Create a copy of this instance.
+        new = self._copy_with(unit=unit)
+        # Update the new instance's internal `scale` attribute.
+        new._scale = self._scale * (unit // self._unit)
+        # Return the new instance.
+        return new
 
     def _subscript_standard(self, indices):
         """Perform standard array subscription.
@@ -446,8 +534,21 @@ class Array(numpy.lib.mixins.NDArrayOperatorsMixin, Quantity):
         If `index` is ``None`` or an empty iterable, this method will produce
         the entire array. Otherwise, it will create the requested subarray from
         `self.data`. It will always attempt to use a cached version of the full
-        array before loading from disk.
+        array before loading from disk. The specific algorithm is as follows:
+
+        - If `index` is "missing" (i.e., `None` or an empty iterable object, but
+          not 0), the caller wants the full array.
         
+            - If we already have the full array, return it.
+            - Else, read it, save it, and return it.
+
+        - Else, if `index` is not missing, the caller wants a subarray.
+
+            - If we already have the full array, subscript and return it.
+            - Else, continue
+
+        - Else, read and subscript it, and return the subarray.
+
         The reasoning behind this algorithm is as follows: If we need to load
         the full array at any point, we may as well save it because subscripting
         an in-memory `numpy.ndarray` is much faster than re-reading from disk
